@@ -3,7 +3,8 @@ import gym
 import gym_sf
 
 render_mode = "rgb_array_list" # "rgb_array" "rgb_array_list"
-env = gym.make("four-room-v0", render_mode=render_mode, max_episode_steps=5000, video=True)
+env = gym.make("four-room-v0", render_mode=render_mode, max_episode_steps=5000,
+               video=True)
 # env = gym.make("four-room-v0", render_mode='human', new_step_api=True, max_episode_steps=5000)
 terminated = False
 truncated = False
